@@ -1,7 +1,7 @@
 
 """
-__version__ = "$Revision: 1.45 $"
-__date__ = "$Date: 2004/10/10 02:32:18 $"
+__version__ = "$Revision: 1.47 $"
+__date__ = "$Date: 2005/12/25 13:53:15 $"
 """
 
 import wx
@@ -391,12 +391,22 @@ class BitmapCanvas(widget.Widget, wx.Window):
     def getPixel(self, xy):
         return self._bufImage.GetPixelPoint(xy)
 
+    def getTextExtent(self, aString):
+        return self._bufImage.GetTextExtent(aString)
+
+    def getFullTextExtent(self, aString):
+        return self._bufImage.GetFullTextExtent(aString)
+
     def refresh(self, enableAutoRefresh=False):
         if enableAutoRefresh:
             self.autoRefresh = True
         dc = wx.ClientDC(self)
         dc.BlitPointSize((0, 0), (self._size[0], self._size[1]), self._bufImage, (0, 0))
-        #self._delegate.Refresh()
+        # KEA 2005-03-26
+        # this is necessary to force a screen update on the Mac
+        if wx.Platform == '__WXMAC__':
+            #self.canvas.Refresh()
+            self.Update()
 
 
     def _onPaint(self, evt):
