@@ -1,12 +1,12 @@
 
 """
-+__version__ = "$Revision: 1.27 $"
-+__date__ = "$Date: 2004/08/11 14:08:24 $"
++__version__ = "$Revision: 1.28 $"
++__date__ = "$Date: 2004/11/07 18:13:13 $"
 """
 
 import wx
 from wx.lib.mixins.listctrl import ColumnSorterMixin, ListCtrlAutoWidthMixin
-from types import TupleType, ListType, StringType, NoneType, IntType
+from types import TupleType, ListType, StringTypes, NoneType, IntType
 from PythonCard import event, widget
 
 class MultiColumnListEvent(event.Event):
@@ -231,7 +231,7 @@ class MultiColumnList(widget.Widget, wx.ListCtrl, ColumnSorterMixin, ListCtrlAut
                 aList = map(lambda x:x + blanks, aList)
             else:
                 aList = map(lambda x:x[:numcols], aList)
-        elif isinstance(aList[0], StringType):
+        elif isinstance(aList[0], StringTypes):
             blanks = [''] * (numcols - 1)
             aList = map(lambda x:[x] + blanks, aList)
         else:
@@ -248,7 +248,7 @@ class MultiColumnList(widget.Widget, wx.ListCtrl, ColumnSorterMixin, ListCtrlAut
         # to copy the portion below the insertion point
         if position < numitems:
             currentitems = self._getItems()[position:]
-            if isinstance(currentitems[0], StringType):
+            if isinstance(currentitems[0], StringTypes):
                 currentitems = map(lambda x:[x], currentitems)
             aList = aList + currentitems
 
@@ -289,7 +289,7 @@ class MultiColumnList(widget.Widget, wx.ListCtrl, ColumnSorterMixin, ListCtrlAut
             self.resizeLastColumn(self.GetColumnWidth(numcols-1))
 
     def _setColumnHeadings(self, aList):
-        if isinstance(aList, ListType) or isinstance(aList, TupleType) or isinstance(aList, StringType):
+        if isinstance(aList, ListType) or isinstance(aList, TupleType) or isinstance(aList, StringTypes):
             pass
         else:
             raise 'invalid MultiColumnList.SetHeading value: ', aList
@@ -298,7 +298,7 @@ class MultiColumnList(widget.Widget, wx.ListCtrl, ColumnSorterMixin, ListCtrlAut
         self.itemDataMap = {}
         self._autoresize = 1
 
-        if isinstance(aList, StringType):
+        if isinstance(aList, StringTypes):
             self.InsertColumn(0,aList,width=self.GetBestVirtualSize()[0])
             self._columnHeadings = [aList]
             return
@@ -314,12 +314,12 @@ class MultiColumnList(widget.Widget, wx.ListCtrl, ColumnSorterMixin, ListCtrlAut
             numcols = self._maxColumns
             self._columnHeadings = aList[:numcols]
 
-        if isinstance(aList[0], StringType):
+        if isinstance(aList[0], StringTypes):
             for i in xrange(numcols):
                 self.InsertColumn(i, aList[i], width=wx.LIST_AUTOSIZE)
         elif isinstance(aList[0], ListType) or isinstance(aList[0], TupleType):
             w = len(aList[0])
-            if w == 2 and isinstance(aList[0][0], StringType) and isinstance(aList[0][1], IntType):
+            if w == 2 and isinstance(aList[0][0], StringTypes) and isinstance(aList[0][1], IntType):
                 flag = 0
                 for i in xrange(numcols):
                     if aList[i][1] != wx.LIST_AUTOSIZE:
@@ -328,7 +328,7 @@ class MultiColumnList(widget.Widget, wx.ListCtrl, ColumnSorterMixin, ListCtrlAut
                 if flag:
                     self._autoresize = 0
             elif w == 3 and \
-                   isinstance(aList[0][0], StringType) and \
+                   isinstance(aList[0][0], StringTypes) and \
                    isinstance(aList[0][1], IntType) and \
                    isinstance(aList[0][2], IntType):
                 flag = 0
@@ -338,7 +338,7 @@ class MultiColumnList(widget.Widget, wx.ListCtrl, ColumnSorterMixin, ListCtrlAut
                     self.InsertColumn(i, aList[i][0], format=aList[i][2], width=aList[i][1])
                 if flag:
                     self._autoresize = 0
-            elif w == 1 and isinstance(aList[0][0], StringType):
+            elif w == 1 and isinstance(aList[0][0], StringTypes):
                 for i in xrange(numcols):
                     self.InsertColumn(i, aList[i][0], width=wx.LIST_AUTOSIZE)
                 self._autoresize = 1
@@ -429,7 +429,7 @@ class MultiColumnList(widget.Widget, wx.ListCtrl, ColumnSorterMixin, ListCtrlAut
             return
 
         # If just simple list of strings convert it to a single column list
-        if isinstance(aList[0], StringType):
+        if isinstance(aList[0], StringTypes):
             aList = map(lambda x:[x], aList)
         elif isinstance(aList[0], ListType) or isinstance(aList[0], TupleType):
             pass
