@@ -1,7 +1,7 @@
 
 """
-__version__ = "$Revision: 1.134 $"
-__date__ = "$Date: 2004/10/03 19:21:33 $"
+__version__ = "$Revision: 1.135 $"
+__date__ = "$Date: 2005/12/25 16:40:08 $"
 """
 
 import wx
@@ -86,7 +86,7 @@ class MessageWatcher(wx.Frame, event.EventListener):
 
         sizer2.Add(self.hideTimers, 0, wx.LEFT | wx.RIGHT | wx.BOTTOM, 5)
         sizer2.Add((5, 5), 1)  # spacer
-        self.hideUnused = wx.CheckBox(panel, -1, 'Hide unused',
+        self.hideUnused = wx.CheckBox(panel, -1, 'Hide unused (#)',
                                      wx.DefaultPosition, wx.DefaultSize,
                                      wx.NO_BORDER)
         # KEA 2004-04-10
@@ -107,6 +107,11 @@ class MessageWatcher(wx.Frame, event.EventListener):
             self.msgHistory.StyleSetSpec(stc.STC_STYLE_DEFAULT, "face:Arial,size:9")
         else:
             self.msgHistory.StyleSetSize(stc.STC_STYLE_DEFAULT, wx.NORMAL_FONT.GetPointSize())
+        # KEA 2005-12-25
+        # change the lexer to Python
+        # and denote unused messages as comments (e.g. #mouseUp
+        self.msgHistory.StyleSetSpec(stc.STC_P_COMMENTLINE, "fore:#7F7F7F")
+        self.msgHistory.SetLexer(stc.STC_LEX_PYTHON)
         self.msgHistory.SetUseHorizontalScrollBar(0)
         self.msgHistory.SetMarginWidth(1,0)
         self.msgHistory.SetUndoCollection(0)
@@ -133,7 +138,7 @@ class MessageWatcher(wx.Frame, event.EventListener):
         if used:
             eventText = eventName + ' : '  + sourceName
         else:
-            eventText = '(' + eventName + ' : '  + sourceName + ')'
+            eventText = '# ' + eventName + ' : '  + sourceName
 
         # show timer events?
         if (eventName == 'timer' and self.hideTimers.GetValue()):
