@@ -18,10 +18,15 @@
               'name':'menuFile',
               'label':'File',
               'items': [ 
+                { 'type':'MenuItem',
+                  'name':'menuFileAbout',
+                  'label':'&About\tAlt+a',
+                  'command':'about' },
                 { 'type':'MenuItem',
                   'name':'menuFileExit',
                   'label':'E&xit\tAlt+X',
-                  'command':'exit' } ] }
+                  'command':'exit' } ,
+                  ] },
         ]       
     },
 
