@@ -1,7 +1,7 @@
 
 """
-__version__ = "$Revision: 1.190 $"
-__date__ = "$Date: 2004/09/28 21:24:24 $"
+__version__ = "$Revision: 1.197 $"
+__date__ = "$Date: 2006/01/13 23:33:37 $"
 """
 
 import os, sys
@@ -20,7 +20,7 @@ try:
     
     import wx
     assert wx.VERSION >= (2, 5, 2, 8)
-except:
+except AssertionError:
     from wxPython.wx import wxPySimpleApp, wxFrame, wxMessageDialog, wxICON_EXCLAMATION, wxOK, wxVERSION_STRING
     app = wxPySimpleApp()
     frame = wxFrame(None, -1, "Minimum Requirements Not Met")
@@ -133,24 +133,53 @@ class WidgetDict(UserDict.UserDict, event.Changeable):
         return self.data.keys()
 
 
+# KEA 2005-03-30
+# revised to support platform-specific resource files
 def internationalResourceName(base):
-    aFileName = base + ".rsrc.py"
+    postfix = ".rsrc.py"
+    # build up a list of possible filenames
+    # in order of preference and use the first one that exists
+    filenames = [base + postfix]
+    
+    if wx.Platform == '__WXMSW__':
+        platform = 'win'
+    elif wx.Platform == '__WXGTK__':
+        platform = 'gtk'
+    elif wx.Platform == '__WXMAC__':
+        platform = 'mac'
+    else:
+        platform = None
+    if platform:
+        filenames.insert(0, base + '.' + platform + postfix)
+        
     try:
         default = locale.getdefaultlocale()
     except:
         default = None
     log.debug('default: ' + str(default))
+    
     if default and default[0] is not None:
         language, country = default[0].split('_')
-        languageCountryName = base + '.' + language + '_' + country + ".rsrc.py"
-        languageOnlyName = base + '.' + language + ".rsrc.py"
-        if os.path.exists(languageCountryName):
-            aFileName = languageCountryName
-        elif os.path.exists(languageOnlyName):
-            aFileName = languageOnlyName
-        log.debug(language + ' ' + country + ' ' + languageCountryName + ' ' + \
-                  languageOnlyName + ' ' + aFileName)
-    return aFileName
+        log.debug(language + ' ' + country)
+        # languageOnlyName
+        filenames.insert(0, base + '.' + language + postfix)
+        # languageCountryName
+        filenames.insert(0, base + '.' + language + '_' + country + postfix)
+        # now with platform specified as well
+        if platform:
+            filenames.insert(0, base + '.' + platform + '.' + language + postfix)
+            filenames.insert(0, base + '.' + platform + '.' + language + '_' + country + postfix)
+        
+    log.debug(filenames)
+    # AGT 2005-05-17 Detect missing resource file, give some warning; no clean recovery possible.
+    filename = None
+    for f in filenames:
+        if os.path.exists(f):
+            filename = f
+            break
+    if not filename:
+        print "no resource file for", base
+    return filename
 
 
 # KEA 2002-09-09
@@ -597,6 +626,14 @@ class Background(Scriptable, wx.Frame, event.EventSource):
         event.EventSource.__init__(self)
         self.id = wx.NewId()
         self.resource = aBgRsrc
+        # KEA 2005-12-29
+        # this is a hack to make sure the background has a defined spec
+        # attribute for documentation purposes, but the spec should be defined
+        # just like we do for components
+        # Also need to verify that the currently defined component specs are 
+        # being used to enforce the attributes when loading a resource and not
+        # just using the default defined in spec.py
+        self._spec = aBgRsrc._spec.getEntry('Background')
         self.application = wx.GetApp()
         self.setName(aBgRsrc.name)
         self.setImage(aBgRsrc.image)
@@ -612,9 +649,18 @@ class Background(Scriptable, wx.Frame, event.EventSource):
 
         # KEA 2004-01-18
         # have to explicitly declare the close box in wxPython 2.5
-        style = wx.MINIMIZE_BOX | wx.SYSTEM_MENU | wx.CAPTION | wx.CLOSE_BOX
-        if aBgRsrc.style == ['resizeable']:
+        if aBgRsrc.style == []:
+            style = wx.MINIMIZE_BOX | wx.SYSTEM_MENU | wx.CAPTION | wx.CLOSE_BOX
+        elif aBgRsrc.style == ['resizeable']:
             style = wx.DEFAULT_FRAME_STYLE
+        else:
+            style = 0
+            for i in aBgRsrc.style:
+                try:             # intended to catch all errors !
+                    style |= eval(i)
+                except:
+                    pass
+
         # First, call the base class' __init__ method to create the frame
         wx.Frame.__init__(self, aParent,
                             self.id, 
@@ -1188,6 +1234,8 @@ class Background(Scriptable, wx.Frame, event.EventSource):
     size = property(_getSize, _setSize, doc="size of the background") 
     title = property(wx.Frame.GetTitle, wx.Frame.SetTitle)
     visible = property(wx.Frame.IsShown, wx.Frame.Show, doc="whether the background window is visible") 
+    maximized = property(wx.Frame.IsMaximized, wx.Frame.Maximize, doc="whether the background window is maximized") 
+    minimized = property(wx.Frame.IsIconized, wx.Frame.Iconize, doc="whether the background window is minimized") 
 
 
 # KEA 2004-09-28
