@@ -1,14 +1,13 @@
 #!/usr/bin/python
 
 """
-__version__ = "$Revision: 1.42 $"
-__date__ = "$Date: 2004/08/15 17:34:58 $"
+__version__ = "$Revision: 1.43 $"
+__date__ = "$Date: 2005/12/13 11:13:25 $"
 """
 
-from PythonCard import dialog, graphic, log, model, timer, util
+from PythonCard import dialog, graphic, log, model, timer, util, EXIF
 import wx
 import os, sys
-from PythonCard import EXIF
 import zipfile
 from cStringIO import StringIO
 
@@ -62,7 +61,6 @@ class SlideShow(model.Background):
             # on certain HTML pages
             self.components.htmlView.enabled = 0
 
-
         # this is the code from pictureViewer
         # instead of a file argument, slideshow
         # should take either a file or directory
@@ -100,10 +98,9 @@ class SlideShow(model.Background):
     def on_timer(self, event):
         self.displayNextFile()
 
-    # need to enable keyPresses
-    # for backgrounds without a component that accepts
-    # keyPresses
     def on_keyPress(self, event):
+        # need to enable keyPresses
+        # for backgrounds without a component that accepts keyPresses
         keyCode = event.GetKeyCode()
         #print keyCode
         if keyCode == wx.WXK_UP or keyCode == wx.WXK_HOME:
@@ -122,8 +119,8 @@ class SlideShow(model.Background):
         self.components.htmlView.size = size
         self.displayFile()
 
-    # always display the file limited to the current size of buffer
     def displayFile(self):
+        # always display the file limited to the current size of buffer
         if self.filename is not None:
             if htmlFile(self.filename):
                 self.components.htmlView.text = self.filename
@@ -176,83 +173,42 @@ class SlideShow(model.Background):
                 #self.components.bufOff.setFocus()
 
     def openFile(self, path, slideNumber=None):
-        if self.zip:
-            self.openFileInZip(path, slideNumber)
-            return
-
-        if not os.path.exists(path):
-            return
-
         self.filename = path
-        if htmlFile(path):
+        if htmlFile(self.filename):
             title = os.path.split(self.filename)[-1]
         else:
-            f = open(path, 'rb')
-            tags = EXIF.process_file(f)
-            f.close()
-            try:
+            if self.zip:
+                data = self.zip.read(self.filename)
+                tags = EXIF.process_file(StringIO(data))
+                log.debug("Getting %s from zip file" % self.filename)
+                self.bmp = graphic.Bitmap()
+                self.bmp.setImageBits(wx.ImageFromStream(StringIO(data)))
+            else:
+                if not os.path.exists(self.filename):
+                    return
+                f = open(self.filename, 'rb')
+                tags = EXIF.process_file(f)
+                f.close()
+                log.debug("Getting %s from file" % self.filename)
+                self.bmp = graphic.Bitmap(self.filename)
+            if tags.has_key('Image Orientation'):
                 # the repr() is something like
                 # (0x0112) Short=8 @ 54
                 # but the str() is just 1, 8, etc.
                 orientation = int(str(tags['Image Orientation']))
-                #print path
-                #print 'Image Orientation: %d' % orientation
-                #print 'Thumbnail Orientation: %s' % tags['Thumbnail Orientation']
-            except:
+            else:
                 orientation = 1
-    
-            self.bmp = graphic.Bitmap(self.filename)
+            log.debug('Image Orientation: %d' % orientation)
+            if tags.has_key('Thumbnail Orientation'):
+                log.debug('Thumbnail Orientation: %s' % tags['Thumbnail Orientation'])
             if orientation == 8:
                 # need to rotate the image
                 # defaults to clockwise, 0 means counter-clockwise
-                #print "rotating"
                 self.bmp.rotate90(0)
             elif orientation == 6:
                 self.bmp.rotate90(1)
-
             size = self.bmp.getSize()
             title = os.path.split(self.filename)[-1] + "  %d x %d" % size
-            
-        if slideNumber is not None:
-            title = title + "  Slide: %d of %d" % (slideNumber + 1, len(self.fileList))
-        self.title = title
-        self.displayFile()
-
-    def openFileInZip(self, path, slideNumber=None):
-        self.filename = path
-        if htmlFile(path):
-            title = os.path.split(self.filename)[-1]
-        else:
-            ##info = self.zip.NameToInfo[path]
-            data = self.zip.read(path)
-            tags = EXIF.process_file(StringIO(data))
-            #f = open(path, 'rb')
-            #tags=EXIF.process_file(f)
-            #f.close()
-            try:
-                # the repr() is something like
-                # (0x0112) Short=8 @ 54
-                # but the str() is just 1, 8, etc.
-                orientation = int(str(tags['Image Orientation']))
-                #print path
-                #print 'Image Orientation: %d' % orientation
-                #print 'Thumbnail Orientation: %s' % tags['Thumbnail Orientation']
-            except:
-                orientation = 1
-
-            self.bmp = graphic.Bitmap()
-            self.bmp.setImageBits(wx.ImageFromStream(StringIO(data)))
-            if orientation == 8:
-                # need to rotate the image
-                # defaults to clockwise, 0 means counter-clockwise
-                #print "rotating"
-                self.bmp.rotate90(0)
-            elif orientation == 6:
-                self.bmp.rotate90(1)
-
-            size = self.bmp.getSize()
-            title = os.path.split(self.filename)[-1] + "  %d x %d" % size
-            
         if slideNumber is not None:
             title = title + "  Slide: %d of %d" % (slideNumber + 1, len(self.fileList))
         self.title = title
@@ -261,7 +217,6 @@ class SlideShow(model.Background):
     def displayNextFile(self):
         if self.fileList is None:
             return
-
         index = self.fileIndex + 1
         if self.loop and index == len(self.fileList):
             index = 0
@@ -296,7 +251,7 @@ class SlideShow(model.Background):
             try:
                 interval = int(result.text) * 1000
                 self.interval = interval
-            except:
+            except ValueError:
                 pass
 
     def buildFileListFromFile(self, path):
@@ -305,28 +260,27 @@ class SlideShow(model.Background):
             txt = f.read()
             f.close()
             self.fileList = txt.splitlines()
-        except:
+        except IOError:
             pass
 
     def buildFileListFromDirectory(self, path, recurse=True):
         self.zip = None
         self.directory = path
         fileList = util.dirwalk(path, ['*'], recurse)
+        log.debug('Directory file list: %s' % fileList)
         # self.fileList should be filtered here
         self.fileList = []
         self.fileIndex = -1
         for path in fileList:
             if imageFile(path) or htmlFile(path):
-                #print "path", path
                 self.fileList.append(path)
         self.fileList = util.caseinsensitive_sort(self.fileList)
         
     def buildFileListFromZip(self, path):
-        #print path
         self.zip = zipfile.ZipFile(path)
-        #print self.zip.namelist()
         self.directory = None
         fileList = self.zip.namelist()
+        log.debug('Zip file list: %s' % fileList)
         # self.fileList should be filtered here
         self.fileList = []
         self.fileIndex = -1
@@ -336,10 +290,7 @@ class SlideShow(model.Background):
                 ext = ext[1:]
             if ext in ['bmp', 'gif', 'jpeg', 'jpg', 'pcx', 
                        'png', 'pnm', 'tif', 'tiff', 'xbm', 'xpm']:
-                #if imageFile(f) or htmlFile(f):
-                #print "path", path
                 self.fileList.append(f)
-        #print self.fileList
 
     def on_menuSlideshowChooseZip_select(self, event):
         wildcard = "Zip archives (*.zip)|*.ZIP;*.zip"
@@ -417,7 +368,7 @@ class SlideShow(model.Background):
                     if n >= 0 and n < len(self.fileList):
                         self.fileIndex = n
                         self.openFile(self.fileList[self.fileIndex], self.fileIndex)
-                except:
+                except ValueError:
                     pass
 
     def on_mouseUp(self, event):
@@ -439,16 +390,16 @@ class SlideShow(model.Background):
         if self.fileList is not None and self.fileList != []:
             path = self.fileList[self.fileIndex]
             if imageFile(path):
-                #print "image", path
+                log.debug("image: %s" % path)
+                viewer = os.path.abspath(os.path.join('..', 'pictureViewer', 'pictureViewer.py'))
+                if " " in path:
+                    path = '"' + path + '"'
                 try:
-                    viewer = os.path.abspath(os.path.join('..', 'pictureViewer', 'pictureViewer.py'))
-                    if " " in path:
-                        path = '"' + path + '"'
                     util.runScript(viewer, path)
-                except:
+                except: # Fail gracefully if displaying fails
                     pass
             elif htmlFile(path):
-                #print "html", path
+                log.debug("html: %s" % path)
                 import webbrowser
                 webbrowser.open(path, 1, 1)
 
@@ -457,7 +408,6 @@ class SlideShow(model.Background):
         self.bmp = None
         event.skip()
 
-
 if __name__ == '__main__':
     app = model.Application(SlideShow)
     app.MainLoop()
