@@ -35,7 +35,7 @@ if fileitem.filename and fileitem.file:
         fp.close()
 
         print "Upload of file %s was successful." % filename
-    except:
+    except Exception, msg: # Should check for a particular Exception
         print "Upload of file %s failed." % filename
         
 else:
