@@ -1,8 +1,8 @@
 #!/usr/bin/python
 
 """
-__version__ = "$Revision: 1.1 $"
-__date__ = "$Date: 2004/07/28 17:05:54 $"
+__version__ = "$Revision: 1.2 $"
+__date__ = "$Date: 2005/09/18 03:59:22 $"
 """
 
 import wx
@@ -203,7 +203,7 @@ class MyRequestHandler(CGIHTTPRequestHandler):
                 os.dup2(self.rfile.fileno(), 0)
                 os.dup2(self.wfile.fileno(), 1)
                 os.execve(scriptfile, args, env)
-            except:
+            except Exception, msg: # Should test for a particular Exception
                 self.server.handle_error(self.request, self.client_address)
                 os._exit(127)
 
@@ -227,7 +227,7 @@ class MyRequestHandler(CGIHTTPRequestHandler):
             self.log_message("command: %s", cmdline)
             try:
                 nbytes = int(length)
-            except:
+            except Exception, msg: # Should test for a particular Exception
                 nbytes = 0
             files = popenx(cmdline, 'b')
             fi = files[0]
@@ -334,7 +334,7 @@ class MyRequestHandler(CGIHTTPRequestHandler):
             mdt = time.gmtime(s[8])
             lastModified = date_time_string(s[8])
             size = str(s[6])
-        except:
+        except Exception, msg: # Should test for a particular exception
             mdt = None
             lastModified = None
             size = None
