@@ -1,11 +1,14 @@
 """
-__version__ = "$Revision: 1.6 $"
-__date__ = "$Date: 2004/04/14 00:17:43 $"
+__version__ = "$Revision: 1.7 $"
+__date__ = "$Date: 2005/09/18 03:59:21 $"
 """
 
 import wx
 import sndhdr
 
+class SoundFileError(Exception):
+    pass
+
 class Sound:
     """
     Feeble beginnings of a class for playing sounds.
@@ -28,7 +31,7 @@ class Sound:
         else:
             self._sndType = None
         if not self._sndType:
-            raise
+            raise SoundFileError, 'This is not a valid sound file'
 
     def play(self, async=True, looped=False) :
         if self._sndType:
