@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 """
-__version__ = "$Revision: 1.125 $"
-__date__ = "$Date: 2004/08/18 16:24:56 $"
+__version__ = "$Revision: 1.126 $"
+__date__ = "$Date: 2005/12/19 23:18:04 $"
 
 PythonCard Editor (codeEditor) wiki page
 http://wiki.wxpython.org/index.cgi/PythonCardEditor
@@ -1211,11 +1211,12 @@ class CodeEditor(model.Background):
         global help_url
 
         if sys.platform.startswith("win"):
-        # KEA 2003-10-15
-        # hack for Python 2.3 Windows help file
+        # KEA 2003-10-15   AGT 2005-12-20
+        # BIG hack for Python 2.3 Windows help file (or Python 2.4)
         # need to decide on a clean way of handling various doc options
             fn = os.path.dirname(os.__file__)
-            fn = os.path.join(fn, os.pardir, "Doc", "Python23.chm")
+            chmfile = "Python" + sys.version[0] + sys.version[2] + ".chm"
+            fn = os.path.join(fn, os.pardir, "Doc", chmfile)
             fn = os.path.normpath(fn)
             if os.path.isfile(fn):
                 os.startfile(fn)
