@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 """
-__version__ = "$Revision: 1.10 $"
-__date__ = "$Date: 2004/10/17 16:39:13 $"
+__version__ = "$Revision: 1.15 $"
+__date__ = "$Date: 2005/12/29 02:48:25 $"
 
 PythonCard Editor (codeEditor) wiki page
 http://wiki.wxpython.org/index.cgi/PythonCardEditor
@@ -181,6 +181,7 @@ class TabCodeEditor(model.Background):
 
         sizer2.Add(self.components.popComponentNames)
         sizer2.Add(self.components.popComponentEvents)
+        sizer2.Add( (10,21) )
 
         sizer1.Add(sizer2, 0)
         sizer1.Add(self.components.notebook, 1, wx.EXPAND)
@@ -244,15 +245,19 @@ class TabCodeEditor(model.Background):
 
     def updateTitleBar(self):
         title = self.title
+        pageText = self.components.notebook.GetPageText(self.currentPageNumber)
         if self.currentPage:
             modified = self.currentDocument.GetModify()
         else:
             modified = ''
         if modified and title[0] != '*':
             self.title = '* ' + title + ' *'
+            self.components.notebook.SetPageText(self.currentPageNumber, '* ' + pageText + ' *')
+            self.panel.Refresh()
         elif not modified and title[0] == '*':
             self.title = title[2:-2]
-        
+            self.components.notebook.SetPageText(self.currentPageNumber, pageText[2:-2])
+            self.panel.Refresh()
 
     # these are event handlers bound above
     # since they aren't automatically bound by PythonCard
@@ -1040,11 +1045,11 @@ class TabCodeEditor(model.Background):
                 pass
 
     def execScriptlet(self, filename):
-        try:
-            command = 'execfile(%r)' % filename
-            self.application.shell.run(command=command, prompt=0, verbose=0)
-        except:
-            pass
+        #try:
+        command = 'execfile(%r)' % filename
+        self.application.shell.run(command=command, prompt=0, verbose=0)
+        #except:
+        #    pass
 
     def on_menuScriptletRunScriptlet_select(self, event):
         self.loadShell()
@@ -1239,11 +1244,12 @@ class TabCodeEditor(model.Background):
         global help_url
 
         if sys.platform.startswith("win"):
-        # KEA 2003-10-15
-        # hack for Python 2.3 Windows help file
+        # KEA 2003-10-15   AGT 2005-12-20
+        # BIG hack for Python 2.3 Windows help file or Python 2.4
         # need to decide on a clean way of handling various doc options
             fn = os.path.dirname(os.__file__)
-            fn = os.path.join(fn, os.pardir, "Doc", "Python23.chm")
+            chmfile = "Python" + sys.version[0] + sys.version[2] + ".chm"
+            fn = os.path.join(fn, os.pardir, "Doc", chmfile)
             fn = os.path.normpath(fn)
             if os.path.isfile(fn):
                 os.startfile(fn)
@@ -1265,6 +1271,7 @@ class TabCodeEditor(model.Background):
             self.updateStatusBar()
             self.updateTitleBar()
             self.setResourceFile()
+            wx.CallAfter(self.currentPage.SetFocus)
         event.skip()
             
 
