@@ -1,8 +1,8 @@
 #!/usr/bin/python
 
 """
-__version__ = "$Revision: 1.219 $"
-__date__ = "$Date: 2004/09/30 21:16:24 $"
+__version__ = "$Revision: 1.225 $"
+__date__ = "$Date: 2005/12/24 04:45:57 $"
 """
 
 # TODO: Start using exceptions!
@@ -435,6 +435,13 @@ class ResourceEditor(model.Background):
         self.lastPosition = position
         #print "    self.lastPosition", self.lastPosition
 
+    def on_mouseDoubleClick(self, event):
+        # AGT 2005-05-12 Should be unnecessary - but seems to prevent the problem where a double-click
+        #  was causing subsequent GetEventObjects to "stick" on the button
+        ##print "dc",  event.GetEventObject().GetName()
+        pass
+
+
     def on_mouseDown(self, event):
         # KEA 2003-03-23
         # protect against panel events
@@ -677,17 +684,11 @@ class ResourceEditor(model.Background):
         if not self.startName:
             return
 
-        try:
-            # Windows
-            xOffset = event.x - self.offset[0]
-            yOffset = event.y - self.offset[1]
-        except:
-            # Mac OS X and Linux/GTK
-            #x, y = event.GetPosition()
-            globalPosition = wx.GetMousePosition()
-            x, y = self.components[self.resizingHandleTarget].ScreenToClient(globalPosition)
-            xOffset = x - self.offset[0]
-            yOffset = y - self.offset[1]
+        # AGT 2005-05-17 Removed obsolete Windows variant
+        globalPosition = wx.GetMousePosition()
+        x, y = self.components[self.resizingHandleTarget].ScreenToClient(globalPosition)
+        xOffset = x - self.offset[0]
+        yOffset = y - self.offset[1]
             
         xStartOffset = self.startPosition[0] + e * xOffset
         yStartOffset = self.startPosition[1] + n * yOffset
@@ -1060,8 +1061,13 @@ class ResourceEditor(model.Background):
 
 
     def fixComponentOrder(self, name):
-        for c in self.components.order:
-            self.components[c].Lower()
+        # KEA 2005-12-23
+        # Lower() doesn't appear to always work correctly, 
+        # so use Raise instead with a reversed list
+        r = self.components.order[:]
+        r.reverse()
+        for c in r:
+            self.components[c].Raise()
         
         if self.application.pw is not None:
             self.application.pw.clearComponentsList()
@@ -1492,29 +1498,38 @@ class ResourceEditor(model.Background):
         dlg.showModal()
         dlg.destroy()
 
-    def on_filePreviewDialog_command(self, event):
-        # we should prompt to save the .rsrc.py file if needed
-        # or in the case of a new file, do a save as before attempting
-        # to do a preview
-        self.previewDialog()
-
-    def runScript(self, useInterpreter):
+    def autoSaveFile(self):
         # KEA 2004-05-08
         # auto-save code taken from codeEditor
         if self.filename is None:
             save = self.saveChanges()
             if save == "Cancel" or save == "No":
                 # don't do anything, just go back to editing
-                return
+                return False
             else:
                 if not self.on_menuFileSaveAs_select(None):
                     # they didn't actually save, just go back
                     # to editing
-                    return
+                    return False
         elif self.documentChanged:
             # auto-save
             self.saveFile()
+            return True
+        return True
+                
+    def on_filePreviewDialog_command(self, event):
+        # we should prompt to save the .rsrc.py file if needed
+        # or in the case of a new file, do a save as before attempting
+        # to do a preview
+        if not self.autoSaveFile(): return
+        if self.filename is None:
+            # KEA 2002-03-25
+            # should probably present an error dialog here
+            return
+        self.previewDialog()
 
+    def runScript(self, useInterpreter):
+        if not self.autoSaveFile(): return
         if self.filename is None:
             # KEA 2002-03-25
             # should probably present an error dialog here
