@@ -2,8 +2,8 @@
 """
 Created: 2001/10/12
 
-__version__ = "$Revision: 1.20 $"
-__date__ = "$Date: 2004/05/11 14:35:16 $"
+__version__ = "$Revision: 1.21 $"
+__date__ = "$Date: 2005/03/28 05:46:59 $"
 
 """
 
@@ -417,6 +417,12 @@ class BitmapTurtle(AbstractTurtle):
         #self.dc.DrawLine(x, y, x+1, y+1)
         #self._goto(x, y)   # actually this isn't equivelant
 
+        # KEA 2005-03-26
+        # this is necessary to force a screen update on the Mac
+        if wx.Platform == '__WXMAC__' and self.canvas.autoRefresh:
+            #self.canvas.Refresh()
+            self.canvas.Update()
+
     def line(self, x1, y1, x2, y2):
         """draws a line from x1, y1 to x2, y2 using the current
         pen color and width
@@ -426,6 +432,12 @@ class BitmapTurtle(AbstractTurtle):
         ###self.dc.DrawLine(x1, y1, x2, y2)
         self.canvas.drawLine((round(x1), round(y1)), (round(x2), round(y2)))
 
+        # KEA 2005-03-26
+        # this is necessary to force a screen update on the Mac
+        if wx.Platform == '__WXMAC__' and self.canvas.autoRefresh:
+            #self.canvas.Refresh()
+            self.canvas.Update()
+
     # probably replace this with a wxPython primitive for polygons
     # so we can support filled polys...
     # def polygon(self, sides, distance):
@@ -456,6 +468,12 @@ class BitmapTurtle(AbstractTurtle):
         self.canvas.clear()
         self._dirty = False
 
+        # KEA 2005-03-26
+        # this is necessary to force a screen update on the Mac
+        if wx.Platform == '__WXMAC__' and self.canvas.autoRefresh:
+            #self.canvas.Refresh()
+            self.canvas.Update()
+
     # need to enhance this to support the various
     # color settings: colourName, rgb
     """ valid named colors from wxWindows http://www.lpthe.jussieu.fr/~zeitlin/wxWindows/docs/wxwin64.htm#wxcolourdatabase
@@ -627,6 +645,10 @@ yellow, yellow green
             self.canvas.drawLine((round(x0), round(y0)), (round(x1), round(y1)))
                 
         if not self._drawingTurtle:
+            # KEA 2005-03-26
+            # this is necessary to force a screen update on the Mac
+            if wx.Platform == '__WXMAC__' and self.canvas.autoRefresh:
+                self.canvas.Update()
             if self._visible:
                 # this is necessary to avoid an endless loop as drawTurtle uses _goto
                 #self._visible = 0
