@@ -1,7 +1,7 @@
 
 """
-__version__ = "$Revision: 1.133 $"
-__date__ = "$Date: 2004/09/14 17:28:45 $"
+__version__ = "$Revision: 1.136 $"
+__date__ = "$Date: 2005/03/28 17:29:37 $"
 """
 
 import wx
@@ -37,13 +37,6 @@ class WidgetSpec( component.ComponentSpec ) :
             }
         attributes.update(subclassAttributes)
         component.ComponentSpec.__init__( self, name, parent, events, attributes )        
-
-    def getMinimalResourceDict(self, name):
-        """
-        Class method that returns the minimal resource dictionary needed to create a component.
-        The spec will provide the optional attributes when the Resource is created.
-        """
-        return {'type':self.getName(), 'name':name}
        
 
 class Widget(component.Component):
@@ -58,12 +51,10 @@ class Widget(component.Component):
    # _spec = WidgetSpec()
 
     def __init__(self, aParent, aResource):
-        component.Component.__init__(self)
+        component.Component.__init__(self, aResource)
         self._parent = aParent
         self._resource = aResource
-        self._name = aResource.name   
         self._setUserdata(self._resource.userdata)
-        self._setCommand(self._resource.command)
         # KEA 2004-04-23
         # Controls are enabled and visible by default
         # so no need to enable and call Show unless False.
@@ -101,12 +92,6 @@ class Widget(component.Component):
     # and tools have to be checked for use of a parent variable
     def getParent(self):
         return self.GetParent() 
-
-    def _getName(self):
-        return self._name 
-
-    def _setName(self, aString):
-        raise AttributeError, "name attribute is read-only"
     
     def _getToolTip(self):
         try:
@@ -149,12 +134,6 @@ class Widget(component.Component):
     def _setUserdata(self, aString):
         self._userdata = aString
 
-    def _setCommand( self, aString ) :
-        self._command = aString
-
-    def _getCommand( self ) :
-        return self._command
-
     def _getDefaultColor( self, aColor ) :
         if aColor is None :
             return wx.NullColour
@@ -217,12 +196,10 @@ class Widget(component.Component):
     # if a subclass overrides any of the methods below then it needs to
     # set the property as well so the appropriate method gets used
     backgroundColor = property(_getBackgroundColor, _setBackgroundColor)
-    command = property(_getCommand, _setCommand)
     font = property(_getFont, _setFont)
     foregroundColor = property(_getForegroundColor, _setForegroundColor)
     enabled = property(_getEnabled, _setEnabled)
     id = property(_getId, _setId)
-    name = property(_getName, _setName)
     #position = property(wx.Window.GetPositionTuple, wx.Window.Move)
     position = property(_getPosition, _setPosition)
     size = property(_getSize, _setSize)
@@ -275,6 +252,9 @@ class Widget(component.Component):
         if 0:
             print "\nBINDING...", self.name
 
+        actionBindings = {}
+        if self.actionBindings is not None:
+            actionBindings = self.actionBindings
         for eventClass in eventList:
         #for eventClass in ButtonEvents:
             # need to figure out a way to avoid the need
@@ -293,6 +273,15 @@ class Widget(component.Component):
                 handler = background.findHandler('on_' + self.name + '_' + eventClass.name)
             if not handler:
                 handler = background.findHandler('on_' + eventClass.name)
+            if not handler:
+                handlerData = actionBindings.get(eventClass.name)
+                if handlerData is not None:
+                    handlerObjectName, handlerFunction = handlerData
+                    handlerObject = background.components.get(handlerObjectName)
+                    if handlerObject is not None:
+                        handler = getattr(handlerObject, handlerFunction, None)
+                    if not handler:
+                        handler = background.findHandler('on_' + handlerObjectName + '_' + handlerFunction)
             if handler or bindUnusedEvents:
                 # only bind events that have an event handler
                 # in this scenario unused events are never bound
@@ -384,7 +373,9 @@ class Widget(component.Component):
         # change to just using the method directly, Handler class not needed
         #handler = self.eventIdToHandler.get(eventType, None)
         handler = self.eventIdToHandler.get(eventType, None)
-        if handler:
+        # KEA 2005-03-28
+        # don't fire events when objects are in the process of being deleted
+        if handler and not aWxEvent.target.IsBeingDeleted():
             event.EventLog.getInstance().log(eventName, self.name, True)
             if 0:
                 print "dispatching", handler.__name__
